==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/actions/image/pixelcolorchanger/PixelColorChangerExtension.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef PIXELCOLORCHANGEREXTENSION_H
#define PIXELCOLORCHANGEREXTENSION_H

#include <QObject>
#include <Action.h>
#include <ActionExtension.h>

class PixelColorChangerExtension : public camitk::ActionExtension {
  Q_OBJECT
    Q_INTERFACES(camitk::ActionExtension);

public:
    /// the constructor
    PixelColorChangerExtension() : ActionExtension() {};

    /// the destructor
    virtual ~PixelColorChangerExtension() {};

    /// initialize all the actions
    virtual void init();
    
    /// Method that return the action extension name
    virtual QString getName() {return "Pixel Color Changer";};
    
    /// Method that return the action extension descrption
    virtual QString getDescription() {return "Extension that allows to change pixel color value (paint image using a pencil)";};

};


#endif // PIXELCOLORCHANGEREXTENSION_H

==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/sdk/actions/image/pixelcolorchanger/PixelColorChangerExtension.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef PIXELCOLORCHANGEREXTENSION_H
#define PIXELCOLORCHANGEREXTENSION_H

#include <QObject>
#include <Action.h>
#include <ActionExtension.h>

class PixelColorChangerExtension : public camitk::ActionExtension {
    Q_OBJECT
    Q_INTERFACES(camitk::ActionExtension);

public:
    /// the constructor
    PixelColorChangerExtension() : ActionExtension() {};

    /// the destructor
    virtual ~PixelColorChangerExtension() {};

    /// initialize all the actions
    virtual void init();

    /// Method that return the action extension name
    virtual QString getName() {
        return "Pixel Color Changer";
    };

    /// Method that return the action extension descrption
    virtual QString getDescription() {
        return "Extension that allows one to change pixel color value (paint image using a pencil)";
    };

};


#endif // PIXELCOLORCHANGEREXTENSION_H
